@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mixgtk_gen_handlers.c :
  * Implementation of the functions declared in mixgtk_gen_handlers.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "01/03/16 00:30:40 jose"
+ *  Last change: Time-stamp: "2001-04-29 12:32:47 jao"
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -24,6 +24,7 @@
 #include <mixlib/mix_vm_command.h>
 #include "mixgtk_gen_handlers.h"
 #include "mixgtk_cmd_dispatcher.h"
+#include "mixgtk_config.h"
 
 void
 on_main_window_destroy (GtkWidget *w, gpointer data)
@@ -93,3 +94,16 @@ on_clear_breakpoints_activate (GtkWidget *w, gpointer data)
   mixgtk_cmd_dispatcher_dispatch (mix_vm_command_to_string (MIX_CMD_CABP));
 }
 
+void
+on_save_on_exit_toggle (GtkWidget *w, gpointer data)
+{
+  mixgtk_config_set_autosave (GTK_CHECK_MENU_ITEM (w)->active);
+}
+
+void
+on_save_activate (GtkWidget *w, gpointer data)
+{
+  mixgtk_config_save ();
+}
+
+
