@@ -1,7 +1,7 @@
 /* -*-c-*- ---------------- mixgtk_gen_handlers.h :
  * general signal handlers declarations
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: <01/03/16 00:29:45 jose>
+ *  Last change: Time-stamp: <2001-04-29 12:32:32 jao>
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -39,6 +39,11 @@ on_file_exit_activate (GtkWidget *w, gpointer data);
 extern void
 on_clear_breakpoints_activate (GtkWidget *w, gpointer data);
 
+extern void
+on_save_on_exit_toggle (GtkWidget *w, gpointer data);
+
+extern void
+on_save_activate (GtkWidget *w, gpointer data);
 
 
 
