@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mixgtk_widgets.c :
  * Implementation of the functions declared in mixgtk_widgets.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "01/03/15 14:42:37 jose"
+ *  Last change: Time-stamp: "2001-04-29 14:32:17 jao"
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -25,6 +25,7 @@
 
 #include <glade/glade.h>
 #include <mixlib/mix.h>
+#include "mixgtk_config.h"
 #include "mixgtk_widgets.h"
 
 /* the glade spec */
@@ -37,6 +38,9 @@ static const gchar *names_[] = {
   "word_dialog",
   "about_dialog",
   "goto_dialog",
+  "color_dialog",
+  "fontsel_dialog",
+  "mixvm_widget",
   "command_prompt",
   "command_log",
   "mixal_clist",
@@ -54,12 +58,12 @@ static const gchar *names_[] = {
   "greater_radio",
   "over_toggle",
   "memory_cells",
-  "memory_scroll",
-  "devices_notebook",
-  "loc_entry",
   "elapsed_label",
   "program_label",
   "uptime_label",
+  "memory_scroll",
+  "devices_notebook",
+  "loc_entry",
   NULL
 };
 
@@ -67,14 +71,27 @@ static const gchar *names_[] = {
 
 #define VERSION_LABEL_ "version_label"
 #define GPL_TEXT_ "gpl_text"
+#define AUTOSAVE_ITEM_ "save_on_exit"
 
 GtkWidget *about_;
 
+static void
+init_autosave_ (void)
+{
+  GtkCheckMenuItem *item = GTK_CHECK_MENU_ITEM
+    (mixgtk_widget_factory_get_by_name (AUTOSAVE_ITEM_));
+  if (item)
+    {
+      gtk_check_menu_item_set_active (item, mixgtk_config_is_autosave ());
+    }
+}
+
 /* create a new factory from an xml glade file */
 gboolean
 mixgtk_widget_factory_init (const char *glade_file)
 {
   GtkWidget *label;
+  
   glade_init ();
   xml_ = glade_xml_new (glade_file, NULL);
   if (!xml_) return FALSE;
@@ -86,6 +103,9 @@ mixgtk_widget_factory_init (const char *glade_file)
   g_return_val_if_fail (label != NULL, FALSE);
   gtk_label_set_text (GTK_LABEL(label), VERSION);
   gtk_widget_show (label);
+  
+  init_autosave_ ();
+  
   return TRUE;
 }
 
