@@ -1,7 +1,7 @@
 /* -*-c-*- ---------------- mixgtk_widgets.h :
  * glade-based factory of mixvm widgets
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: <01/03/15 14:42:13 jose>
+ *  Last change: Time-stamp: <2001-04-27 23:32:16 jao>
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -35,6 +35,9 @@ typedef enum {
   MIXGTK_WIDGET_WORD_DIALOG,	/* input dialog for a mix word */
   MIXGTK_WIDGET_ABOUT_DIALOG,
   MIXGTK_WIDGET_GOTO_DIALOG,
+  MIXGTK_WIDGET_COLORSEL_DIALOG, /* color customization dialog */
+  MIXGTK_WIDGET_FONTSEL_DIALOG,	/* font selection dialog */
+  MIXGTK_WIDGET_MIXVM,		/* virtual machine */
   MIXGTK_WIDGET_PROMPT,		/* command prompt */
   MIXGTK_WIDGET_LOG,		/* command output */
   MIXGTK_WIDGET_MIXAL,		/* mixal source file */
@@ -52,12 +55,12 @@ typedef enum {
   MIXGTK_WIDGET_CMP_G,
   MIXGTK_WIDGET_OVER,
   MIXGTK_WIDGET_CELLS,
-  MIXGTK_WIDGET_CELLS_SCROLL,
-  MIXGTK_WIDGET_DEVICE,
-  MIXGTK_WIDGET_LOC,
   MIXGTK_WIDGET_LAPTIME,
   MIXGTK_WIDGET_PROGTIME,
   MIXGTK_WIDGET_UPTIME,
+  MIXGTK_WIDGET_CELLS_SCROLL,
+  MIXGTK_WIDGET_DEVICE,
+  MIXGTK_WIDGET_LOC,
   MIXGTK_WIDGET_NONE
 } mixgtk_widget_id_t;
 
