@@ -1,7 +1,7 @@
 /* -*-c-*- ---------------- mix.h :
  * Initialisation of the mix library
  * ------------------------------------------------------------------
- * Copyright (C) 2000 Free Software Foundation, Inc.
+ * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 #	include <libintl.h>
 #	define gettext_noop(String)	(String)
 #else
-#	include <intl/libintl.h>
+#	include <intl/libgettext.h>
 #endif 
 
 #define _(String) gettext (String)
