@@ -57,6 +57,12 @@ vm_reset_ (mix_vm_t *vm)
       mix_src_file_delete (vm->src_file);
       vm->src_file = NULL;
     }
+  for (k = 0; k < BD_NO_; ++k)
+    if (vm->devices[k] != NULL)
+      {
+	mix_device_delete (vm->devices[k]);
+	vm->devices[k] = NULL;
+      }
   bp_clear_all_ (vm);
 }
 
@@ -76,8 +82,10 @@ mix_vm_new (void)
     vm->devices[i] = NULL;
   
   vm->clock = mix_vm_clock_new ();
+  vm->factory = mix_device_new;
   
   vm_reset_ (vm);
+
   return vm;
 }
 
@@ -116,6 +124,15 @@ mix_vm_connect_device (mix_vm_t *vm, mix_device_t *device)
   return old;
 }
 
+/* install a device factory for automatic connection */
+void
+mix_vm_set_device_factory (mix_vm_t *vm, mix_device_factory_t factory)
+{
+  g_return_if_fail (vm != NULL);
+  g_return_if_fail (factory != NULL);
+  vm->factory = factory;
+}
+
 /* Reset a vm  (set state as of a newly created one) */
 void
 mix_vm_reset (mix_vm_t * vm)
