@@ -51,6 +51,11 @@ mix_vm_delete(mix_vm_t * vm);
 extern mix_device_t * /* previously connected device */
 mix_vm_connect_device (mix_vm_t *vm, mix_device_t *device);
 
+/* install a device factory for automatic connection */
+typedef mix_device_t * (* mix_device_factory_t) (mix_device_type_t device);
+extern void
+mix_vm_set_device_factory (mix_vm_t *vm, mix_device_factory_t factory);
+
 /* Reset a vm (set state as of a newly created one) */
 extern void
 mix_vm_reset(mix_vm_t * vm);
