@@ -52,7 +52,7 @@ get_dev_ (mix_vm_t *vm, mix_fspec_t type)
 {
   if (type >= BD_NO_) return NULL;
   if (vm->devices[type] == NULL)
-    vm->devices[type] = mix_device_new (type);
+    vm->devices[type] = vm->factory (type);
   return vm->devices[type];
 }
 
